/*
*  for Maemo renamed to play.h and adapted (2009, Reto Zingg)
*
*  Main Mancala Program Module Header -- main.h 
*  $Id: main.h,v 1.1.2.8 2004/01/16 20:49:30 sparrow_hawk Exp $
*
*  Copyright (C) 2003 Kevin Riggle 
*  http://cmancala.sourcefoge.net
*
*  This program is free software; you can redistribute it and/or modify it
*  under the terms of the GNU General Public License as published by the
*  Free Software Foundation; either version 2, or (at your option) any
*  later version.
*
*  This program is distributed in the hope that it will be useful, but
*  WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  General Public License for more details, a copy of which may be found in
*  the file COPYING provided in the main directory of this release.
*
*/

/* path to resource files */
#define RES_PATH "/home/opt/mancala/data"
#define FONT_PATH "/home/opt/mancala/data"

/* various constants */
#define STRING_MAX 1000
#define STONE_MAX 10
#define DELAY_MAX 1
#define DELAY_AI 3000

/* font sizes */
#define TITLE_SIZE 75
#define HOME_SIZE 50
#define BOARD_SIZE 35

#define HMN_WAIT 1
#define HMN_MOVE 2
#define CMP_WAIT 3
#define CMP_MOVE 4
#define GAME_WON 0

#define Y_OFFSET 70

extern int play();

